@@ -49,7 +49,7 @@ import urllib.request
 
 NAME = 'Reflector'
 
-URL = 'https://packages.artixlinux.org/mirrors/status/json/'
+URL = 'https://status.artixlinux.org/mirrors/status/json/'
 
 DISPLAY_TIME_FORMAT = '%Y-%m-%d %H:%M:%S UTC'
 PARSE_TIME_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
